A crate that contains manifest structures used by dxm.
Modules
- artifact
- Contains structures that represent FXServer installation data.
- lockfile
- Contains structures for the lockfile used by dxm.
- profile
- Contains structures that represent FXServer start profile data.
- resource
- Contains structures that represent resource data.
- server
- Contains structures that represent server data.
- sourcefile
- Contains functions for sourcefiles used by dxm. Sourcefiles are used for saving the exact version/URL installed for a specific artifact/resource.
Structs
- Manifest
- The parent manifest structure containing data used by dxm.